==> org-lsst-sal-camera-2.5.0-sources.jar: org/lsst/sal/camera/event/Image_handling_ImageHandler_FitsHandlingConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Image_handling_ImageHandler_FitsHandlingConfigurationEvent extends CameraEvent {
  private final String version;

  private final boolean imagehandlingconfig_FITSAutoSave;

  private final String imagehandlingconfig_FITSDirectoryPattern;

  private final String imagehandlingconfig_FITSFilePattern;

  private final String imagehandlingconfig_FITSRootDirectory;

  private final String imagehandlingconfig_subsystemsToClearOnNewRun;

  private final String imagehandlingconfig_tempFileRelativeLocation;

  private final boolean imagehandlingconfig_useTempFile;

  public Image_handling_ImageHandler_FitsHandlingConfigurationEvent(int priority, String version,
      boolean imagehandlingconfig_FITSAutoSave, String imagehandlingconfig_FITSDirectoryPattern,
      String imagehandlingconfig_FITSFilePattern, String imagehandlingconfig_FITSRootDirectory,
      String imagehandlingconfig_subsystemsToClearOnNewRun,
      String imagehandlingconfig_tempFileRelativeLocation,
      boolean imagehandlingconfig_useTempFile) {
    super (priority);
    this.version = version;
    this.imagehandlingconfig_FITSAutoSave = imagehandlingconfig_FITSAutoSave;
    this.imagehandlingconfig_FITSDirectoryPattern = imagehandlingconfig_FITSDirectoryPattern;
    this.imagehandlingconfig_FITSFilePattern = imagehandlingconfig_FITSFilePattern;
    this.imagehandlingconfig_FITSRootDirectory = imagehandlingconfig_FITSRootDirectory;
    this.imagehandlingconfig_subsystemsToClearOnNewRun = imagehandlingconfig_subsystemsToClearOnNewRun;
    this.imagehandlingconfig_tempFileRelativeLocation = imagehandlingconfig_tempFileRelativeLocation;
    this.imagehandlingconfig_useTempFile = imagehandlingconfig_useTempFile;
  }

  public String getVersion() {
    return version;
  }

  public boolean isImagehandlingconfig_FITSAutoSave() {
    return imagehandlingconfig_FITSAutoSave;
  }

  public String getImagehandlingconfig_FITSDirectoryPattern() {
    return imagehandlingconfig_FITSDirectoryPattern;
  }

  public String getImagehandlingconfig_FITSFilePattern() {
    return imagehandlingconfig_FITSFilePattern;
  }

  public String getImagehandlingconfig_FITSRootDirectory() {
    return imagehandlingconfig_FITSRootDirectory;
  }

  public String getImagehandlingconfig_subsystemsToClearOnNewRun() {
    return imagehandlingconfig_subsystemsToClearOnNewRun;
  }

  public String getImagehandlingconfig_tempFileRelativeLocation() {
    return imagehandlingconfig_tempFileRelativeLocation;
  }

  public boolean isImagehandlingconfig_useTempFile() {
    return imagehandlingconfig_useTempFile;
  }

  @Override
  public String toString() {
    return "Image_handling_ImageHandler_FitsHandlingConfigurationEvent{" + "version=" + version +
        ", imagehandlingconfig_FITSAutoSave=" + imagehandlingconfig_FITSAutoSave +
        ", imagehandlingconfig_FITSDirectoryPattern=" + imagehandlingconfig_FITSDirectoryPattern +
        ", imagehandlingconfig_FITSFilePattern=" + imagehandlingconfig_FITSFilePattern +
        ", imagehandlingconfig_FITSRootDirectory=" + imagehandlingconfig_FITSRootDirectory +
        ", imagehandlingconfig_subsystemsToClearOnNewRun=" + imagehandlingconfig_subsystemsToClearOnNewRun +
        ", imagehandlingconfig_tempFileRelativeLocation=" + imagehandlingconfig_tempFileRelativeLocation +
        ", imagehandlingconfig_useTempFile=" + imagehandlingconfig_useTempFile +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private boolean imagehandlingconfig_FITSAutoSave;

    private String imagehandlingconfig_FITSDirectoryPattern;

    private String imagehandlingconfig_FITSFilePattern;

    private String imagehandlingconfig_FITSRootDirectory;

    private String imagehandlingconfig_subsystemsToClearOnNewRun;

    private String imagehandlingconfig_tempFileRelativeLocation;

    private boolean imagehandlingconfig_useTempFile;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder imagehandlingconfig_FITSAutoSave(boolean imagehandlingconfig_FITSAutoSave) {
      this.imagehandlingconfig_FITSAutoSave = imagehandlingconfig_FITSAutoSave;
      return this;
    }

    public Builder imagehandlingconfig_FITSDirectoryPattern(
        String imagehandlingconfig_FITSDirectoryPattern) {
      this.imagehandlingconfig_FITSDirectoryPattern = imagehandlingconfig_FITSDirectoryPattern;
      return this;
    }

    public Builder imagehandlingconfig_FITSFilePattern(String imagehandlingconfig_FITSFilePattern) {
      this.imagehandlingconfig_FITSFilePattern = imagehandlingconfig_FITSFilePattern;
      return this;
    }

    public Builder imagehandlingconfig_FITSRootDirectory(
        String imagehandlingconfig_FITSRootDirectory) {
      this.imagehandlingconfig_FITSRootDirectory = imagehandlingconfig_FITSRootDirectory;
      return this;
    }

    public Builder imagehandlingconfig_subsystemsToClearOnNewRun(
        String imagehandlingconfig_subsystemsToClearOnNewRun) {
      this.imagehandlingconfig_subsystemsToClearOnNewRun = imagehandlingconfig_subsystemsToClearOnNewRun;
      return this;
    }

    public Builder imagehandlingconfig_tempFileRelativeLocation(
        String imagehandlingconfig_tempFileRelativeLocation) {
      this.imagehandlingconfig_tempFileRelativeLocation = imagehandlingconfig_tempFileRelativeLocation;
      return this;
    }

    public Builder imagehandlingconfig_useTempFile(boolean imagehandlingconfig_useTempFile) {
      this.imagehandlingconfig_useTempFile = imagehandlingconfig_useTempFile;
      return this;
    }

    public Image_handling_ImageHandler_FitsHandlingConfigurationEvent build() {
      return new Image_handling_ImageHandler_FitsHandlingConfigurationEvent(priority, version, imagehandlingconfig_FITSAutoSave, imagehandlingconfig_FITSDirectoryPattern, imagehandlingconfig_FITSFilePattern, imagehandlingconfig_FITSRootDirectory, imagehandlingconfig_subsystemsToClearOnNewRun, imagehandlingconfig_tempFileRelativeLocation, imagehandlingconfig_useTempFile);
    }
  }
}

==> org-lsst-sal-camera-2.5.2-sources.jar: org/lsst/sal/camera/event/Image_handling_ImageHandler_FitsHandlingConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Image_handling_ImageHandler_FitsHandlingConfigurationEvent extends CameraEvent {
  private final String version;

  private final boolean imagehandlingconfig_FITSAutoSave;

  private final String imagehandlingconfig_FITSDirectoryPattern;

  private final String imagehandlingconfig_FITSFilePattern;

  private final String imagehandlingconfig_FITSRootDirectory;

  private final String imagehandlingconfig_subsystemsToClearOnNewRun;

  private final String imagehandlingconfig_tempFileRelativeLocation;

  private final boolean imagehandlingconfig_useTempFile;

  public Image_handling_ImageHandler_FitsHandlingConfigurationEvent(String version,
      boolean imagehandlingconfig_FITSAutoSave, String imagehandlingconfig_FITSDirectoryPattern,
      String imagehandlingconfig_FITSFilePattern, String imagehandlingconfig_FITSRootDirectory,
      String imagehandlingconfig_subsystemsToClearOnNewRun,
      String imagehandlingconfig_tempFileRelativeLocation,
      boolean imagehandlingconfig_useTempFile) {
    this.version = version;
    this.imagehandlingconfig_FITSAutoSave = imagehandlingconfig_FITSAutoSave;
    this.imagehandlingconfig_FITSDirectoryPattern = imagehandlingconfig_FITSDirectoryPattern;
    this.imagehandlingconfig_FITSFilePattern = imagehandlingconfig_FITSFilePattern;
    this.imagehandlingconfig_FITSRootDirectory = imagehandlingconfig_FITSRootDirectory;
    this.imagehandlingconfig_subsystemsToClearOnNewRun = imagehandlingconfig_subsystemsToClearOnNewRun;
    this.imagehandlingconfig_tempFileRelativeLocation = imagehandlingconfig_tempFileRelativeLocation;
    this.imagehandlingconfig_useTempFile = imagehandlingconfig_useTempFile;
  }

  public String getVersion() {
    return version;
  }

  public boolean isImagehandlingconfig_FITSAutoSave() {
    return imagehandlingconfig_FITSAutoSave;
  }

  public String getImagehandlingconfig_FITSDirectoryPattern() {
    return imagehandlingconfig_FITSDirectoryPattern;
  }

  public String getImagehandlingconfig_FITSFilePattern() {
    return imagehandlingconfig_FITSFilePattern;
  }

  public String getImagehandlingconfig_FITSRootDirectory() {
    return imagehandlingconfig_FITSRootDirectory;
  }

  public String getImagehandlingconfig_subsystemsToClearOnNewRun() {
    return imagehandlingconfig_subsystemsToClearOnNewRun;
  }

  public String getImagehandlingconfig_tempFileRelativeLocation() {
    return imagehandlingconfig_tempFileRelativeLocation;
  }

  public boolean isImagehandlingconfig_useTempFile() {
    return imagehandlingconfig_useTempFile;
  }

  @Override
  public String toString() {
    return "Image_handling_ImageHandler_FitsHandlingConfigurationEvent{" + "version=" + version +
        ", imagehandlingconfig_FITSAutoSave=" + imagehandlingconfig_FITSAutoSave +
        ", imagehandlingconfig_FITSDirectoryPattern=" + imagehandlingconfig_FITSDirectoryPattern +
        ", imagehandlingconfig_FITSFilePattern=" + imagehandlingconfig_FITSFilePattern +
        ", imagehandlingconfig_FITSRootDirectory=" + imagehandlingconfig_FITSRootDirectory +
        ", imagehandlingconfig_subsystemsToClearOnNewRun=" + imagehandlingconfig_subsystemsToClearOnNewRun +
        ", imagehandlingconfig_tempFileRelativeLocation=" + imagehandlingconfig_tempFileRelativeLocation +
        ", imagehandlingconfig_useTempFile=" + imagehandlingconfig_useTempFile +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private boolean imagehandlingconfig_FITSAutoSave;

    private String imagehandlingconfig_FITSDirectoryPattern;

    private String imagehandlingconfig_FITSFilePattern;

    private String imagehandlingconfig_FITSRootDirectory;

    private String imagehandlingconfig_subsystemsToClearOnNewRun;

    private String imagehandlingconfig_tempFileRelativeLocation;

    private boolean imagehandlingconfig_useTempFile;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder imagehandlingconfig_FITSAutoSave(boolean imagehandlingconfig_FITSAutoSave) {
      this.imagehandlingconfig_FITSAutoSave = imagehandlingconfig_FITSAutoSave;
      return this;
    }

    public Builder imagehandlingconfig_FITSDirectoryPattern(
        String imagehandlingconfig_FITSDirectoryPattern) {
      this.imagehandlingconfig_FITSDirectoryPattern = imagehandlingconfig_FITSDirectoryPattern;
      return this;
    }

    public Builder imagehandlingconfig_FITSFilePattern(String imagehandlingconfig_FITSFilePattern) {
      this.imagehandlingconfig_FITSFilePattern = imagehandlingconfig_FITSFilePattern;
      return this;
    }

    public Builder imagehandlingconfig_FITSRootDirectory(
        String imagehandlingconfig_FITSRootDirectory) {
      this.imagehandlingconfig_FITSRootDirectory = imagehandlingconfig_FITSRootDirectory;
      return this;
    }

    public Builder imagehandlingconfig_subsystemsToClearOnNewRun(
        String imagehandlingconfig_subsystemsToClearOnNewRun) {
      this.imagehandlingconfig_subsystemsToClearOnNewRun = imagehandlingconfig_subsystemsToClearOnNewRun;
      return this;
    }

    public Builder imagehandlingconfig_tempFileRelativeLocation(
        String imagehandlingconfig_tempFileRelativeLocation) {
      this.imagehandlingconfig_tempFileRelativeLocation = imagehandlingconfig_tempFileRelativeLocation;
      return this;
    }

    public Builder imagehandlingconfig_useTempFile(boolean imagehandlingconfig_useTempFile) {
      this.imagehandlingconfig_useTempFile = imagehandlingconfig_useTempFile;
      return this;
    }

    public Image_handling_ImageHandler_FitsHandlingConfigurationEvent build() {
      return new Image_handling_ImageHandler_FitsHandlingConfigurationEvent(version, imagehandlingconfig_FITSAutoSave, imagehandlingconfig_FITSDirectoryPattern, imagehandlingconfig_FITSFilePattern, imagehandlingconfig_FITSRootDirectory, imagehandlingconfig_subsystemsToClearOnNewRun, imagehandlingconfig_tempFileRelativeLocation, imagehandlingconfig_useTempFile);
    }
  }
}
